package alg;

import java.io.*;


class TermValue{  // term is either a constant or an expression
  int num;        // it can have integer
  String sg;      // or string value
  int endIndex;   // start there to search for the next term in the input string
}

public class Expression {

static String [] variables = new String [26];     
static boolean [] varChanged = new boolean[26];  // register changed variables

static TermValue readStringConstant(String inputSg, int index){
   int startIndex = ++index;  // skip the opening quotes
   while (inputSg.charAt(index) != '"')
     index++;
   TermValue sgConstVal = new TermValue();
   sgConstVal.sg = inputSg.substring(startIndex, index);
   sgConstVal.endIndex = index+1; // return the index of the first char past the closing quotes
   return sgConstVal;
}

static TermValue readIntegerConstant(String inputSg, int index){
   TermValue intConstVal = new TermValue();
   intConstVal.num = 0;
   while (('0' <= inputSg.charAt(index)) && (inputSg.charAt(index) <= '9') )
     intConstVal.num = intConstVal.num*10 + Character.digit(inputSg.charAt(index++), 10);
   intConstVal.endIndex = index;
   return intConstVal;
}

// read a variable identifier from the input string and return the value of the variable
static TermValue evalVariable(String inputSg, int index){
   TermValue result = new TermValue();
   result.sg = variables[inputSg.charAt(index)-97];
   result.endIndex = index+1;
   return result;
}

// evaluate the Insert function when the value of its parameters is known
static String functionInsert(String sgWhere, int position, String sgWhat) {
  if (position <= 0)
     return sgWhat + sgWhere;
  if (position < sgWhere.length())
     return sgWhere.substring(0, position)
             + sgWhat + sgWhere.substring(position, sgWhere.length());
  // remains: position >= sgWhere.length()
  return sgWhere + sgWhat;
}

// evaluate the Delete function when the value of its parameters is known
static String functionDelete(String sgWhere, int startPos, int endPos) {
  if (sgWhere.length() == 0)
     return sgWhere;
  if ((endPos < startPos) || (endPos < 0) || (startPos >= sgWhere.length()))
     return sgWhere; // odd start and/or end positions, no change to string at all
  if (startPos < 0) startPos = 0;
  if (endPos >= sgWhere.length()) endPos = sgWhere.length()-1;
  // now the positions are not pathological
  return sgWhere.substring(0, startPos)+ sgWhere.substring(endPos+1, sgWhere.length());
}

// evaluate the Length function when the value of its parameters is known
static int functionLength(String sgOfWhat) {
  return sgOfWhat.length();
}

static TermValue evalExpression(String inputSg, int index) {
 TermValue termVal = new TermValue();
 termVal.sg = "";
 int numParam1, numParam2;
 String sgParam1, sgParam2;

 switch (inputSg.charAt(index)) {
   case 'I': {
     // evaluate (recursively) the values of parameters of the Insert function
     termVal = evalExpression(inputSg, index+2); // skip over "I("
     sgParam1 = termVal.sg;
     termVal = evalExpression(inputSg, termVal.endIndex+1); // skip over ','
     numParam1 = termVal.num;
     termVal = evalExpression(inputSg, termVal.endIndex+1);  // skip over ','
     sgParam2 = termVal.sg;
     // now just apply the Insert function to the evaluated parameters
     termVal.sg = functionInsert(sgParam1, numParam1, sgParam2);
     // and skip over the closing bracket ')' to tell the calling proc where to continue
     termVal.endIndex++;
     break;
   }
   case 'D': {
     termVal = evalExpression(inputSg, index+2); // skip over "D("
     sgParam1 = termVal.sg;
     termVal = evalExpression(inputSg, termVal.endIndex+1); // skip over ','
     numParam1 = termVal.num;
     termVal = evalExpression(inputSg, termVal.endIndex+1);  // skip over ','
     numParam2 = termVal.num;
     termVal.sg = functionDelete(sgParam1, numParam1, numParam2);
     termVal.endIndex++;
     break;
   }
   case 'L': {
     termVal = evalExpression(inputSg, index+2); // skip over "L("
     sgParam1 = termVal.sg;
     termVal.num = functionLength(sgParam1);
     termVal.endIndex++;
     break;
   }
   case '"':  {
     termVal = readStringConstant(inputSg, index);
     break;
   }
   case'0': case'1':case '2':case'3':case'4':case'5':case '6':case'7':case'8':case '9': {
     termVal = readIntegerConstant(inputSg, index);
     break;
   }
   case'a':case'b':case'c':case'd':case'e':case'f':case'g':case'h':case'i':case'j':
   case'k':case'l':case'm':case'n':case'o':case'p':case'q':case'r':case's':case't':
   case'u':case'v':case'w':case'x':case'y':case'z': {
     termVal = evalVariable(inputSg, index);
     break;
   }
 }
 return termVal;
}

static void evalCommand(String inputSg) {
  int index = 0;
  char variableName = inputSg.charAt(index);
  index++; //move over variable name
  TermValue result = evalExpression(inputSg, index+1); //  skip the '=' sign
  variables[variableName-97] = result.sg;
  varChanged[variableName-97] = true;
}

static void evalProgram() throws IOException{
  BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
  String inputLine; 
  char variableName;
  while (true) {
    inputLine = br.readLine();
    if (inputLine.equals("end"))
      break;
    evalCommand(inputLine);
  } 
}

public static void main(String[] args) throws IOException{
  for(int i = 0; i < variables.length; i++) {
    variables[i] = "";                        // initialize the variables
    varChanged[i] = false;
  }
  evalProgram();
  for(int i = 0; i < variables.length; i++)   // print the results
    if (varChanged[i] == true) 
      System.out.printf("%s=\"%s\"\n", ""+(char)(i+97), variables[i]);
}

}
