package alg;

import java.io.*;

// Each function which reads and evaluates a substring of the input string
// returns two values:
// (1) a string/integer value of the substring
// (2) the index where next evaluation will start, i.e the index of the
//  end of the processed substring increased by 1.
// The class Result serves this purpose, thus all relevant functions
// return (1) and (2) simultaneously in a single instance of this class.


class TermValue{  // term is either a constant or an expression
  int num;        // it can have integer
  String sg;      // or string value
  int endIndex;   // start there to search for the next term in the input string
}

public class ExpressionBasic {

// read a string constant from the input string and return its value
static TermValue readStringConstant(String inputSg, int index){
   int startIndex = ++index;  // skip the opening quotes
   while (inputSg.charAt(index) != '"')
     index++;
   TermValue sgConstVal = new TermValue();
   sgConstVal.sg = inputSg.substring(startIndex, index);
   sgConstVal.endIndex = index+1; // return the index of the first char past the closing quotes
   return sgConstVal;
}

// read an integer constant from the input string and return its value
static TermValue readIntegerConstant(String inputSg, int index){
   TermValue intConstVal = new TermValue();
   intConstVal.num = 0;
   while (('0' <= inputSg.charAt(index)) && (inputSg.charAt(index) <= '9') )
     intConstVal.num = intConstVal.num*10 + Character.digit(inputSg.charAt(index++), 10);
   intConstVal.endIndex = index;
   return intConstVal;
}

// evaluate the Insert function when the value of its parameters is known
static String functionInsert(String sgWhere, int position, String sgWhat) {
  if (position <= 0)
     return sgWhat + sgWhere;
  if (position < sgWhere.length())
     return sgWhere.substring(0, position)
             + sgWhat + sgWhere.substring(position, sgWhere.length());
  // remains: position >= sgWhere.length()
  return sgWhere + sgWhat;
}

static TermValue evalExpression(String inputSg, int index) {
 TermValue result = new TermValue();
 result.sg = "";
 int numParam1, numParam2;
 String sgParam1, sgParam2;

 switch (inputSg.charAt(index)) {
   case 'I': {
     // evaluate (recursively) the values of parameters of the Insert function
     result = evalExpression(inputSg, index+2); // skip over "I("
     sgParam1 = result.sg;
     result = evalExpression(inputSg, result.endIndex+1); // skip over ','
     numParam1 = result.num;
     result = evalExpression(inputSg, result.endIndex+1);  // skip over ','
     sgParam2 = result.sg;
     // now just apply the Insert function to the evaluated parameters
     result.sg = functionInsert(sgParam1, numParam1, sgParam2);
     // and skip over the closing bracket ')' to tell the calling proc where to continue
     result.endIndex++;
     break;
   }
    case '"':  { 
     result = readStringConstant(inputSg, index);
     break;
   }
   case'0': case'1':case '2':case'3':case'4':case'5':case '6':case'7':case'8':case '9': {
     result = readIntegerConstant(inputSg, index);
     break;
   }
 }
 return result;
}

  public static void main(String[] args) throws IOException{
   BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
  System.out.printf("\"%s\"\n", evalExpression(br.readLine(), 2).sg);
  }
}
